
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '38.2.0',
    'branch_nick': 'release-38-LTS',
    'revision_id': 'af0cedfc38c83fa06e4b82991d0c04a1129440a9',
    'revno': 13963
}
